@@ -1,7 +1,7 @@
 /*
  ccd.c -- CCD sheet format structure;
 
- Copyright (C) 2013, 2014 Bruno Félix Rezende Ribeiro <oitofelix@gnu.org>
+ Copyright (C) 2013, 2014, 2015 Bruno Félix Rezende Ribeiro <oitofelix@gnu.org>
 
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
@@ -128,7 +128,7 @@ stream2ccd (FILE *stream, struct ccd *ccd)
 				   section;*/
 
       /* Temporary entry values; these are used as place holders to
-	 detect `scanf' assignments and, except INDEX_tmp, are not
+	 detect 'scanf' assignments and, except INDEX_tmp, are not
 	 used in any other fashion.  It works that way because this
 	 function disregards the CCD sheet original numbering to avoid
 	 invalid input from resulting unpredictable behavior.
